#$Id$

package Data::Squirrel::DB_File;

use strict;
use vars qw(@ISA);

@ISA = qw(Data::Squirrel);

use Data::Squirrel;
use Apache::Session::Lock::File;
use Data::Squirrel::Store::DB_File;
use Apache::Session::Generate::MD5;
use Apache::Session::Serialize::Storable;

sub populate 
{
    my $self = shift;

    $self->{object_store} = new Data::Squirrel::Store::DB_File $self;
    $self->{lock_manager} = new Apache::Session::Lock::File $self;
    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
    $self->{serialize}    = \&Apache::Session::Serialize::Storable::serialize;
    $self->{unserialize}  = \&Apache::Session::Serialize::Storable::unserialize;

    return $self;
}

sub list_ids 
{
    my($self)=@_;
    return $self->{object_store}->list_ids($self);
}


1;

__END__

=pod

=head1 NAME

Data::Squirrel::DB_File - An implementation of Data::Squirrel

=head1 SYNOPSIS

 use Data::Squirrel::DB_File;
 
 tie %hash, 'Data::Squirrel::DB_File', {
    FileName      => 'sessions.db',
    LockDirectory => '/var/lock/sessions',
 };

=head1 DESCRIPTION

This module is an implementation of Data::Squirrel.  It uses the DB_File backing
store and the DB_File locking scheme.  You must specify the directory for the
object store and the directory for locking in arguments to the constructor. See
the example, and the documentation for Data::Squirrel::Store::DB_File and
Apache::Session::Lock::DB_File.

=head1 AUTHOR

Philip Gwyn

=head1 SEE ALSO

L<Data::Squirrel::File>
L<Data::Squirrel::File>, L<Data::Squirrel>

=cut

$Log$