# $Id$

package Data::Squirrel::File;
use strict;
use vars qw(@ISA);

@ISA = qw(Data::Squirrel);

use Data::Squirrel;
use Data::Squirrel::Store::File;
use Apache::Session::Lock::File;
use Apache::Session::Generate::MD5;
use Apache::Session::Serialize::Storable;

sub DEBUG {0}

sub populate 
{
    my $self = shift;

    $self->{object_store} = new Data::Squirrel::Store::File $self;
    $self->{lock_manager} = new Apache::Session::Lock::File $self;
    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
    $self->{serialize}    = \&Apache::Session::Serialize::Storable::serialize;
    $self->{unserialize}  = \&Apache::Session::Serialize::Storable::unserialize;

    return $self;
}

sub list_ids
{
    my($self)=@_;

    my $directory = $self->{args}->{Directory} || $Apache::Session::Store::File::Directory;
    die "The directory for object storage must be passed as an argument or set in httpd.conf" 
        unless defined $directory;

    # get all known object IDs
    opendir(DIR, $directory) || die $!;
    
    local $self->{data}={};
    my @ids;
    foreach my $id (grep {-f "$directory/$_"} readdir(DIR)) { 
        DEBUG and warn "Validating $id\n";
        $self->{data}{_session_id}=$id;
        eval {$self->{validate}->($self)};
        DEBUG and $@ and warn $@;
        next if $@;         
        DEBUG and warn "It's an object file\n";
        push @ids, $id;
    }
    closedir DIR;
    return @ids if wantarray;
    return \@ids;
}

1;

__END__

=pod

=head1 NAME

Data::Squirrel::File - An implementation of Data::Squirrel

=head1 SYNOPSIS

 use Data::Squirrel::File;
 
 tie %hash, 'Data::Squirrel::File', {
    Directory => '/tmp/sessions',
    LockDirectory   => '/var/lock/sessions',
 };

=head1 DESCRIPTION

This module is an implementation of Data::Squirrel.  It uses the File backing
store and the File locking scheme.  You must specify the directory for the
object store and the directory for locking in arguments to the constructor. See
the example, and the documentation for Data::Squirrel::Store::File and
Apache::Session::Lock::File.

=head1 AUTHOR

Philip Gwyn

=head1 SEE ALSO

L<Data::Squirrel::DB_File>
L<Data::Squirrel::MySQL>, L<Data::Squirrel>

=cut


$Log$