# $Id$

package Data::Squirrel::MySQL;

use strict;
use vars qw(@ISA $VERSION);

$VERSION = '1.01';
@ISA = qw(Data::Squirrel);

use Data::Squirrel;
use Apache::Session::Lock::MySQL;
use Data::Squirrel::Store::MySQL;
use Apache::Session::Generate::MD5;
use Apache::Session::Serialize::Storable;

sub populate 
{
    my $self = shift;

    $self->{object_store} = new Data::Squirrel::Store::MySQL $self;
    $self->{lock_manager} = new Apache::Session::Lock::MySQL $self;
    $self->{generate}     = \&Apache::Session::Generate::MD5::generate;
    $self->{validate}     = \&Apache::Session::Generate::MD5::validate;
    $self->{serialize}    = \&Apache::Session::Serialize::Storable::serialize;
    $self->{unserialize}  = \&Apache::Session::Serialize::Storable::unserialize;

    return $self;
}

sub list_ids 
{
    my($self)=@_;
    return $self->{object_store}->list_ids($self);
}

1;

__END__

=pod

=head1 NAME

Data::Squirrel::MySQL - An implementation of Data::Squirrel

=head1 SYNOPSIS

 use Data::Squirrel::MySQL;
 
 tie %hash, 'Data::Squirrel::MySQL', {
    DataSource => 'dbi:mysql:sessions',
    UserName   => $db_user,
    Password   => $db_pass,
    LockDataSource => 'dbi:mysql:sessions',
    LockUserName   => $db_user,
    LockPassword   => $db_pass
 };

=head1 DESCRIPTION

This module is an implementation of Data::Squirrel.  It uses the MySQL backing
store and the MySQL locking scheme.  You must specify the directory for the
object store and the directory for locking in arguments to the constructor. See
the example, and the documentation for Data::Squirrel::Store::MySQL and
Apache::Session::Lock::MySQL.

=head1 AUTHOR

Philip Gwyn

=head1 SEE ALSO

L<Data::Squirrel::DB_File>
L<Data::Squirrel::File>, L<Data::Squirrel>

=cut
